@@ -945,7 +945,7 @@ class MapCalcsGeneric(object):
 			S.show(sac, measures, ax)
 		return measures
 
-	def makeRateMap(self, cluster, ax=None):
+	def makeRateMap(self, cluster, ax=None, **kwargs):
 		pos_w = np.ones_like(self.pos_ts)
 		mapMaker = binning.RateMap(self.xy, None, None, pos_w, ppm=self.ppm)
 		spk_w = np.bincount(self.spk_pos_idx, self.spk_clusters==cluster, minlength=self.pos_ts.shape[0])
@@ -956,7 +956,7 @@ class MapCalcsGeneric(object):
 		ratemap = np.ma.MaskedArray(rmap[0], np.isnan(rmap[0]), copy=True)
 		x, y = np.meshgrid(rmap[1][1][0:-1], rmap[1][0][0:-1][::-1])
 		vmax = np.max(np.ravel(ratemap))
-		ax.pcolormesh(x, y, ratemap, cmap=jet, edgecolors='face', vmax=vmax)
+		ax.pcolormesh(x, y, ratemap, cmap=jet, edgecolors='face', vmax=vmax, **kwargs)
 		ax.axis([x.min(), x.max(), y.min(), y.max()])
 		ax.set_aspect('equal')
 		plt.setp(ax.get_xticklabels(), visible=False)
@@ -969,13 +969,17 @@ class MapCalcsGeneric(object):
 		ax.spines['left'].set_visible(False)
 		return rmap
 
-	def makeSpikePathPlot(self, cluster, ax):
+	def makeSpikePathPlot(self, cluster, ax, **kwargs):
+		if 'ms' not in kwargs.keys() or 'markersize' not in kwargs.keys():
+			kwargs['ms'] = 1
+		if 'mec' or 'c' not in kwargs.keys():
+			kwargs['c'] = tcols.colours[1]
+			kwargs['mec'] = tcols.colours[1]
 		ax.plot(self.xy[0], self.xy[1], c=tcols.colours[0], zorder=1)
 		ax.set_aspect('equal')
 		ax.invert_yaxis()
 		idx = self.spk_pos_idx[self.spk_clusters==cluster]
-		spk_colour = tcols.colours[1]
-		ax.plot(self.xy[0,idx], self.xy[1,idx],'s',ms=1, c=spk_colour,mec=spk_colour)
+		ax.plot(self.xy[0,idx], self.xy[1,idx], 's', **kwargs)
 		plt.setp(ax.get_xticklabels(), visible=False)
 		plt.setp(ax.get_yticklabels(), visible=False)
 		ax.axes.get_xaxis().set_visible(False)
@@ -1114,7 +1118,7 @@ class MapCalcsGeneric(object):
 			speedMod.append(spM)
 			
 		d = {'id': cluster, 'gridness': gridness, 'scale': scale, 
-	        'orientation': orientation, 'HDtuning': HDtuning, 
+			'orientation': orientation, 'HDtuning': HDtuning, 
 			'HDangle': HDangle, 'speedCorr': speedCorr, 'speedMod': speedMod}
 		self.spatialStats = pd.DataFrame(d)
 		
